@@ -72,7 +72,7 @@ from sphinx.util.docutils import SphinxDirective
 # this package
 from sphinx_toolbox.utils import Purger, SphinxExtMetadata, metadata_add_version
 
-__all__ = ["Flake8CodesDirective", "setup"]
+__all__ = ("Flake8CodesDirective", "setup")
 
 table_node_purger = Purger("all_flake8_code_table_nodes")
 
@@ -103,12 +103,12 @@ class Flake8CodesDirective(SphinxDirective):
 
 		for code in self.content:
 			if code.strip():
-				try:
+				if hasattr(module, code):
 					description = getattr(module, code)
 					if description.startswith(code):
 						description = description[len(code):]
 					codes.append((code, description.strip()))
-				except AttributeError:
+				else:
 					warnings.warn(f"No such code {code!r}")
 
 		if not codes:
