@@ -114,14 +114,14 @@ from typing_extensions import TypedDict
 # this package
 from sphinx_toolbox.utils import Purger, SphinxExtMetadata, make_github_url, metadata_add_version
 
-__all__ = [
+__all__ = (
 		"pre_commit_node_purger",
 		"pre_commit_f8_node_purger",
 		"parse_hooks",
 		"PreCommitDirective",
 		"Flake8PreCommitDirective",
 		"setup",
-		]
+		)
 
 pre_commit_node_purger = Purger("all_pre_commit_nodes")
 pre_commit_f8_node_purger = Purger("all_pre_commit_f8_nodes")
@@ -168,7 +168,7 @@ class PreCommitDirective(SphinxDirective):
 			"args": parse_hooks,
 			}
 
-	def run(self) -> Sequence[nodes.Node]:  # type: ignore
+	def run(self) -> Sequence[nodes.Node]:  # type: ignore[override]
 		"""
 		Process the content of the directive.
 		"""
@@ -182,7 +182,7 @@ class PreCommitDirective(SphinxDirective):
 				hook_file = directory / ".pre-commit-hooks.yaml"
 				if hook_file.is_file():
 					hooks_dict = YAML(typ="safe", pure=True).load(hook_file.read_text())
-					hooks = [h["id"] for h in hooks_dict]
+					hooks = [h["id"] for h in hooks_dict]  # pylint: disable=loop-invariant-statement
 					break
 			else:
 				warnings.warn("No hooks specified and no .pre-commit-hooks.yaml file found.")
@@ -235,7 +235,7 @@ class Flake8PreCommitDirective(SphinxDirective):
 			}
 	required_arguments = 1  # the plugin version
 
-	def run(self) -> Sequence[nodes.Node]:  # type: ignore
+	def run(self) -> Sequence[nodes.Node]:  # type: ignore[override]
 		"""
 		Process the content of the directive.
 		"""
@@ -273,7 +273,7 @@ class Flake8PreCommitDirective(SphinxDirective):
 		return [pre_commit_node]
 
 
-def revert_8345():
+def revert_8345() -> None:
 	"""
 	Remove the incorrect warning emitted since https://github.com/sphinx-doc/sphinx/pull/8345.
 	"""
@@ -334,7 +334,7 @@ def revert_8345():
 
 		raise sphinx.util.docutils.ElementLookupError
 
-	sphinx.util.docutils.sphinx_domains.lookup_domain_element = lookup_domain_element  # type: ignore
+	sphinx.util.docutils.sphinx_domains.lookup_domain_element = lookup_domain_element  # type: ignore[assignment]
 
 
 @metadata_add_version
