@@ -89,7 +89,7 @@ from domdf_python_tools.paths import PathPlus
 from domdf_python_tools.stringlist import StringList
 from domdf_python_tools.typing import PathLike
 from jinja2 import Template  # nodep
-from pygments.lexer import Lexer  # type: ignore  # nodep
+from pygments.lexer import Lexer  # type: ignore[import]  # nodep
 from pytest_regressions.common import check_text_files  # nodep
 from pytest_regressions.file_regression import FileRegressionFixture  # nodep
 from sphinx.builders import Builder
@@ -108,7 +108,7 @@ from sphinx.util.typing import RoleFunction, TitleGetter
 # this package
 from sphinx_toolbox.utils import Config, SphinxExtMetadata
 
-__all__ = [
+__all__ = (
 		"Sphinx",
 		"run_setup",
 		"RunSetupOutput",
@@ -120,7 +120,7 @@ __all__ = [
 		"html_regression",
 		"LaTeXRegressionFixture",
 		"latex_regression",
-		]
+		)
 
 
 class FakeBuilder(Builder):
@@ -634,7 +634,7 @@ def remove_html_link_tags(page: BeautifulSoup) -> BeautifulSoup:
 	return page
 
 
-def check_html_regression(page: BeautifulSoup, file_regression: FileRegressionFixture):
+def check_html_regression(page: BeautifulSoup, file_regression: FileRegressionFixture) -> None:
 	"""
 	Check an HTML page generated by Sphinx for regressions, using `pytest-regressions`_.
 
@@ -684,7 +684,7 @@ class HTMLRegressionFixture(FileRegressionFixture):
 		jinja2: bool = False,
 		jinja2_namespace: Optional[Dict[str, Any]] = None,
 		**kwargs
-		):
+		) -> None:
 		r"""
 		Check an HTML page generated by Sphinx for regressions, using `pytest-regressions`_.
 
@@ -742,7 +742,7 @@ class HTMLRegressionFixture(FileRegressionFixture):
 
 		if jinja2:
 
-			def check_fn(obtained_filename, expected_filename):
+			def check_fn(obtained_filename: PathPlus, expected_filename: PathPlus):  # noqa: MAN002
 				__tracebackhide__ = True
 
 				expected_filename = PathPlus(expected_filename)
@@ -771,7 +771,7 @@ class HTMLRegressionFixture(FileRegressionFixture):
 
 
 @pytest.fixture()
-def html_regression(datadir, original_datadir, request) -> HTMLRegressionFixture:
+def html_regression(datadir, original_datadir, request) -> HTMLRegressionFixture:  # noqa: MAN001
 	"""
 	Returns an :class:`~.HTMLRegressionFixture` scoped to the test function.
 
@@ -785,7 +785,7 @@ def check_asset_copy(
 		func: Callable[[sphinx.application.Sphinx, Exception], Any],
 		*asset_files: PathLike,
 		file_regression: FileRegressionFixture,
-		):
+		) -> None:
 	r"""
 	Helper to test functions which respond to Sphinx ``build-finished`` events and copy asset files.
 
@@ -824,7 +824,7 @@ class LaTeXRegressionFixture(AdvancedFileRegressionFixture):
 	.. versionadded:: 2.17.0
 	"""
 
-	def check(  # type: ignore[override]
+	def check(  # type: ignore[override]  # noqa: MAN002
 		self,
 		contents: Union[str, StringList],
 		*,
@@ -879,7 +879,7 @@ class LaTeXRegressionFixture(AdvancedFileRegressionFixture):
 
 		if jinja2:
 
-			def check_fn(obtained_filename: PathPlus, expected_filename: PathLike):
+			def check_fn(obtained_filename: PathPlus, expected_filename: PathLike):  # noqa: MAN002
 				__tracebackhide__ = True
 
 				expected_filename = PathPlus(expected_filename)
@@ -922,7 +922,7 @@ class LaTeXRegressionFixture(AdvancedFileRegressionFixture):
 
 
 @pytest.fixture()
-def latex_regression(datadir, original_datadir, request) -> LaTeXRegressionFixture:
+def latex_regression(datadir, original_datadir, request) -> LaTeXRegressionFixture:  # noqa: MAN001
 	"""
 	Returns a :class:`~.LaTeXRegressionFixture` scoped to the test function.
 
