@@ -44,20 +44,19 @@ from typing import Optional
 
 # 3rd party
 import dict2css
-from deprecation_alias import deprecated
 from docutils import nodes
 from domdf_python_tools.paths import PathPlus
 from sphinx.application import Sphinx
 from sphinx.writers.html import HTMLTranslator
 
 # this package
-from sphinx_toolbox import __version__, _css
+from sphinx_toolbox import _css
 from sphinx_toolbox.utils import SphinxExtMetadata, metadata_add_version
 
-__all__ = ["copy_asset_files", "setup"]
+__all__ = ("copy_asset_files", "setup")
 
 
-def visit_container(self: HTMLTranslator, node: nodes.container):
+def visit_container(self: HTMLTranslator, node: nodes.container) -> None:
 	classes = "docutils container"
 	if node.get("is_div", False):
 		# we don't want the CSS for container for these nodes
@@ -69,7 +68,7 @@ def visit_container(self: HTMLTranslator, node: nodes.container):
 	self.body.append(self.starttag(node, "div", CLASS=classes))
 
 
-def depart_container(self: HTMLTranslator, node: nodes.Node):
+def depart_container(self: HTMLTranslator, node: nodes.Node) -> None:
 	self.body.append("</div>\n")
 
 
@@ -82,14 +81,13 @@ def copy_asset_files(app: Sphinx, exception: Optional[Exception] = None) -> None
 
 	.. versionchanged:: 2.7.0
 
-		Renamed from ``copy_assets``.
-		The old name is deprecated an will be removed in 3.0.0
+		Renamed from ``copy_assets``. The former name was kept as an alias until version 3.0.0
 	"""
 
 	if exception:  # pragma: no cover
 		return
 
-	if app.builder is None or app.builder.format.lower() != "html":
+	if app.builder is None or app.builder.format.lower() != "html":  # pragma: no cover
 		return
 
 	# style = StringList([
@@ -116,16 +114,6 @@ def copy_asset_files(app: Sphinx, exception: Optional[Exception] = None) -> None
 	dict2css.dump(_css.tweaks_sphinx_panels_tabs_styles, css_static_dir / "tabs_customise.css")
 
 
-copy_assets = deprecated(
-		deprecated_in="2.7.0",
-		removed_in="3.0.0",
-		current_version=__version__,
-		details="Renamed to 'copy_asset_files'",
-		name="copy_assets",
-		func=copy_asset_files,
-		)
-
-
 @metadata_add_version
 def setup(app: Sphinx) -> SphinxExtMetadata:
 	"""
